You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by so...@apache.org on 2018/05/05 12:57:32 UTC

[maven-surefire] 09/10: Use 'junit-platform-engine' artifact name to identify JUnit Platform

This is an automated email from the ASF dual-hosted git repository.

sor pushed a commit to branch 1330
in repository https://gitbox.apache.org/repos/asf/maven-surefire.git

commit 0cd15b31f24462c292c34cc50128f84381189bc7
Author: Christian Stein <so...@gmail.com>
AuthorDate: Sat May 5 13:46:32 2018 +0200

    Use 'junit-platform-engine' artifact name to identify JUnit Platform
---
 .../java/org/apache/maven/plugin/surefire/AbstractSurefireMojo.java | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/maven-surefire-common/src/main/java/org/apache/maven/plugin/surefire/AbstractSurefireMojo.java b/maven-surefire-common/src/main/java/org/apache/maven/plugin/surefire/AbstractSurefireMojo.java
index 1751356..53d5bf9 100644
--- a/maven-surefire-common/src/main/java/org/apache/maven/plugin/surefire/AbstractSurefireMojo.java
+++ b/maven-surefire-common/src/main/java/org/apache/maven/plugin/surefire/AbstractSurefireMojo.java
@@ -487,9 +487,11 @@ public abstract class AbstractSurefireMojo
 
     /**
      * Allows you to specify the name of the JUnit Platform artifact.
      * If not set, {@code org.junit.platform:junit-platform-commons} will be used.
      */
-    @Parameter( property = "junitPlatformArtifactName", defaultValue = "org.junit.platform:junit-platform-commons" )
+    @Parameter( property = "junitPlatformArtifactName", defaultValue = "org.junit.platform:junit-platform-engine" )
     private String junitPlatformArtifactName;
 
     /**
@@ -487,9 +487,11 @@ public abstract class AbstractSurefireMojo
     /**
      * Allows you to specify the name of the JUnit Platform artifact.
-     * If not set, {@code org.junit.platform:junit-platform-commons} will be used.
+     * If not set, {@code org.junit.platform:junit-platform-engine} will be used.
+     *
+     * @since 2.22.0
      */

-- 
To stop receiving notification emails like this one, please contact
sor@apache.org.